@@ -1,6 +1,6 @@
 package Courriel::Part::Single;
 BEGIN {
-  $Courriel::Part::Single::VERSION = '0.02';
+  $Courriel::Part::Single::VERSION = '0.03';
 }
 
 use strict;
@@ -61,7 +61,7 @@ sub BUILD {
         =~ s/$Courriel::Helpers::LINE_SEP_RE/$Courriel::Helpers::CRLF/g
         if $self->_has_encoded_content();
 
-    $self->_maybe_set_disposition_in_headers();
+    $self->_sync_headers_with_self();
 
     return;
 }
@@ -69,9 +69,22 @@ sub BUILD {
 after _set_headers => sub {
     my $self = shift;
 
-    $self->_maybe_set_disposition_in_headers();
+    $self->_sync_headers_with_self();
+
+    return;
 };
 
+sub _sync_headers_with_self {
+    my $self = shift;
+
+    $self->_maybe_set_disposition_in_headers();
+
+    $self->headers()
+        ->replace( 'Content-Transfer-Encoding' => $self->encoding() );
+
+    return;
+}
+
 sub _maybe_set_disposition_in_headers {
     my $self = shift;
 
@@ -163,7 +176,7 @@ Courriel::Part::Single - A part which does not contain other parts, only content
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
